[Libreoffice-commits] core.git: xmloff/source xmlscript/source xmlsecurity/source

Andrea Gelmini andrea.gelmini at gelma.net
Tue Sep 29 15:14:18 PDT 2015


 xmloff/source/text/XMLAutoTextContainerEventImport.hxx                |    2 +-
 xmloff/source/text/XMLPropertyBackpatcher.hxx                         |    2 +-
 xmloff/source/text/XMLRedlineExport.cxx                               |    2 +-
 xmloff/source/text/txtprmap.cxx                                       |    2 +-
 xmloff/source/transform/EventOASISTContext.cxx                        |    2 +-
 xmlscript/source/xmldlg_imexp/xmldlg_expmodels.cxx                    |    2 +-
 xmlscript/source/xmldlg_imexp/xmldlg_export.cxx                       |    4 ++--
 xmlscript/source/xmldlg_imexp/xmldlg_impmodels.cxx                    |    6 +++---
 xmlsecurity/source/dialogs/resourcemanager.cxx                        |    2 +-
 xmlsecurity/source/framework/buffernode.cxx                           |    2 +-
 xmlsecurity/source/framework/saxeventkeeperimpl.cxx                   |    2 +-
 xmlsecurity/source/framework/saxeventkeeperimpl.hxx                   |    2 +-
 xmlsecurity/source/framework/securityengine.hxx                       |    2 +-
 xmlsecurity/source/helper/xsecctl.hxx                                 |    2 +-
 xmlsecurity/source/xmlsec/mscrypt/securityenvironment_mscryptimpl.cxx |    2 +-
 15 files changed, 18 insertions(+), 18 deletions(-)

New commits:
commit 4678982056a11f978277a2da7a085e4f6ac24afd
Author: Andrea Gelmini <andrea.gelmini at gelma.net>
Date:   Tue Sep 29 18:13:49 2015 +0200

    Fix typos
    
    Change-Id: I2cdfc4e9d8ba1acb7c2548f9394d320c6504207e
    Reviewed-on: https://gerrit.libreoffice.org/18997
    Reviewed-by: Joren De Cuyper <jorendc at libreoffice.org>
    Tested-by: Joren De Cuyper <jorendc at libreoffice.org>

diff --git a/xmloff/source/text/XMLAutoTextContainerEventImport.hxx b/xmloff/source/text/XMLAutoTextContainerEventImport.hxx
index 8f4e66c..b249acc 100644
--- a/xmloff/source/text/XMLAutoTextContainerEventImport.hxx
+++ b/xmloff/source/text/XMLAutoTextContainerEventImport.hxx
@@ -32,7 +32,7 @@ namespace com { namespace sun { namespace star {
 
 /**
  * Import the text:auto-text-container element.
- * This only instantiates text:auto-text-group contexta.
+ * This only instantiates text:auto-text-group context.
  */
 class XMLAutoTextContainerEventImport : public SvXMLImportContext
 {
diff --git a/xmloff/source/text/XMLPropertyBackpatcher.hxx b/xmloff/source/text/XMLPropertyBackpatcher.hxx
index b1bcb00..9396ade 100644
--- a/xmloff/source/text/XMLPropertyBackpatcher.hxx
+++ b/xmloff/source/text/XMLPropertyBackpatcher.hxx
@@ -35,7 +35,7 @@ namespace com { namespace sun { namespace star {
  * yet known.
  *
  * A good example for appropriate use are footnotes and references to
- * footnoes. Internally, the StarOffice API numbers footnotes, and
+ * footnotes. Internally, the LibreOffice API numbers footnotes, and
  * references to footnotes refer to that internal numbering. In the
  * XML file format, these numbers are replaced with name strings. Now
  * if during import of a document a reference to a footnote is
diff --git a/xmloff/source/text/XMLRedlineExport.cxx b/xmloff/source/text/XMLRedlineExport.cxx
index 56ae192..cd4330f 100644
--- a/xmloff/source/text/XMLRedlineExport.cxx
+++ b/xmloff/source/text/XMLRedlineExport.cxx
@@ -593,7 +593,7 @@ void XMLRedlineExport::ExportStartOrEndRedline(
     {
         DBG_ASSERT( !sId.isEmpty(), "Redlines must have IDs" );
 
-        // TODO: use GetRedlineID or elimiate that function
+        // TODO: use GetRedlineID or eliminate that function
         OUStringBuffer sBuffer(sChangePrefix);
         sBuffer.append(sId);
 
diff --git a/xmloff/source/text/txtprmap.cxx b/xmloff/source/text/txtprmap.cxx
index 12d7a29..bcaf317 100644
--- a/xmloff/source/text/txtprmap.cxx
+++ b/xmloff/source/text/txtprmap.cxx
@@ -806,7 +806,7 @@ XMLPropertyMapEntry aXMLFramePropMap[] =
     // RES_KEEP
     // not required
     // RES_URL
-    // not required (exprted as draw:a element)
+    // not required (exported as draw:a element)
     // RES_EDIT_IN_READONLY
     MG_ED( "EditInReadonly",        STYLE,  EDITABLE,                   XML_TYPE_BOOL, 0 ),
     // RES_LAYOUT_SPLIT
diff --git a/xmloff/source/transform/EventOASISTContext.cxx b/xmloff/source/transform/EventOASISTContext.cxx
index 8250d14..78117a7 100644
--- a/xmloff/source/transform/EventOASISTContext.cxx
+++ b/xmloff/source/transform/EventOASISTContext.cxx
@@ -241,7 +241,7 @@ void XMLEventOASISTransformerContext::StartElement(
             case XML_ATACTION_EVENT_NAME:
                 {
                     // Check if the event belongs to a form or control by
-                    // cehcking the 2nd ancestor element, f.i.:
+                    // checking the 2nd ancestor element, f.i.:
                     // <form:button><form:event-listeners><form:event-listener>
                     const XMLTransformerContext *pObjContext =
                         GetTransformer().GetAncestorContext( 1 );
diff --git a/xmlscript/source/xmldlg_imexp/xmldlg_expmodels.cxx b/xmlscript/source/xmldlg_imexp/xmldlg_expmodels.cxx
index 10d03ce..8f24797 100644
--- a/xmlscript/source/xmldlg_imexp/xmldlg_expmodels.cxx
+++ b/xmlscript/source/xmldlg_imexp/xmldlg_expmodels.cxx
@@ -266,7 +266,7 @@ void ElementDescriptor::readCheckBoxModel( StyleBag * all_styles )
         case 1:
             addAttribute( XMLNS_DIALOGS_PREFIX ":checked", "true" );
             break;
-        case 2: // tristate=true exported, checked omitted => dont know!
+        case 2: // tristate=true exported, checked omitted => don't know!
             OSL_ENSURE( bTriState, "### detected tristate value, but TriState is not set!" );
             break;
         default:
diff --git a/xmlscript/source/xmldlg_imexp/xmldlg_export.cxx b/xmlscript/source/xmldlg_imexp/xmldlg_export.cxx
index 89ed0ac..936dd48 100644
--- a/xmlscript/source/xmldlg_imexp/xmldlg_export.cxx
+++ b/xmlscript/source/xmldlg_imexp/xmldlg_export.cxx
@@ -414,7 +414,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
         // dialog:font-relief (none|embossed|engraved) #IMPLIED
         switch (_fontRelief)
         {
-        case awt::FontRelief::NONE: // dont export default
+        case awt::FontRelief::NONE: // don't export default
             break;
         case awt::FontRelief::EMBOSSED:
             pStyle->addAttribute( XMLNS_DIALOGS_PREFIX ":font-relief", "embossed" );
@@ -429,7 +429,7 @@ Reference< xml::sax::XAttributeList > Style::createElement()
         // dialog:font-emphasismark (none|dot|circle|disc|accent|above|below) #IMPLIED
         switch (_fontEmphasisMark)
         {
-        case awt::FontEmphasisMark::NONE: // dont export default
+        case awt::FontEmphasisMark::NONE: // don't export default
             break;
         case awt::FontEmphasisMark::DOT:
             pStyle->addAttribute(XMLNS_DIALOGS_PREFIX ":font-emphasismark", "dot" );
diff --git a/xmlsecurity/source/dialogs/resourcemanager.cxx b/xmlsecurity/source/dialogs/resourcemanager.cxx
index 83420b9..dc06278 100644
--- a/xmlsecurity/source/dialogs/resourcemanager.cxx
+++ b/xmlsecurity/source/dialogs/resourcemanager.cxx
@@ -72,7 +72,7 @@ namespace XmlSec
     /*
         Creates two strings based on the distinguished name which are displayed in the
         certificate details view. The first string contains only the values of the attribute
-        and valudes pairs, which are separated by commas. All escape characters ('"') are
+        and values pairs, which are separated by commas. All escape characters ('"') are
         removed.
         The second string is for the details view at the bottom. It shows the attribute/value
         pairs on different lines. All escape characters ('"') are removed.
diff --git a/xmlsecurity/source/framework/buffernode.cxx b/xmlsecurity/source/framework/buffernode.cxx
index 6d35284..8196f71 100644
--- a/xmlsecurity/source/framework/buffernode.cxx
+++ b/xmlsecurity/source/framework/buffernode.cxx
@@ -199,7 +199,7 @@ void BufferNode::setBlocker(const ElementMark* pBlocker)
  *  empty
  *
  *   NOTES
- *  Because there is only one blocker permited for a BufferNode, so the
+ *  Because there is only one blocker permitted for a BufferNode, so the
  *  old blocker on this BufferNode, if there is one, will be overcasted.
  *
  *   AUTHOR
diff --git a/xmlsecurity/source/framework/saxeventkeeperimpl.cxx b/xmlsecurity/source/framework/saxeventkeeperimpl.cxx
index 4eea017..666063a 100644
--- a/xmlsecurity/source/framework/saxeventkeeperimpl.cxx
+++ b/xmlsecurity/source/framework/saxeventkeeperimpl.cxx
@@ -491,7 +491,7 @@ void SAXEventKeeperImpl::smashBufferNode(
                 /*
                  * If this is a blocker, then remove any out-element data
                  * which caused by blocking. The removal process will stop
-                 * at the next blokcer to avoid removing any useful data.
+                 * at the next blocker to avoid removing any useful data.
                  */
             if (bClearRoot)
             {
diff --git a/xmlsecurity/source/framework/saxeventkeeperimpl.hxx b/xmlsecurity/source/framework/saxeventkeeperimpl.hxx
index 9dea041..31c2f11 100644
--- a/xmlsecurity/source/framework/saxeventkeeperimpl.hxx
+++ b/xmlsecurity/source/framework/saxeventkeeperimpl.hxx
@@ -78,7 +78,7 @@ private:
 
     /*
      * the compressed document handler provided by the XMLDocumentWrapper
-     * component, the handler has more effient method definition that the
+     * component, the handler has more efficient method definition that the
      * normal document handler.
      */
     com::sun::star::uno::Reference<
diff --git a/xmlsecurity/source/framework/securityengine.hxx b/xmlsecurity/source/framework/securityengine.hxx
index 7f7706c..2279b72 100644
--- a/xmlsecurity/source/framework/securityengine.hxx
+++ b/xmlsecurity/source/framework/securityengine.hxx
@@ -81,7 +81,7 @@ protected:
     sal_Int32 m_nIdOfKeyEC;
 
     /*
-     * remembers whether the current opertion has finished.
+     * remembers whether the current operation has finished.
      */
     bool      m_bMissionDone;
 
diff --git a/xmlsecurity/source/helper/xsecctl.hxx b/xmlsecurity/source/helper/xsecctl.hxx
index f988212..f7b933a 100644
--- a/xmlsecurity/source/helper/xsecctl.hxx
+++ b/xmlsecurity/source/helper/xsecctl.hxx
@@ -217,7 +217,7 @@ private:
     com::sun::star::uno::Reference<
         com::sun::star::uno::XInterface > m_xPreviousNodeOnSAXChain;
     /*
-     * whether the preivous node can provide an XInitiazlize interface,
+     * whether the previous node can provide an XInitiazlize interface,
      * use this variable in order to typecast the XInterface to the
      * correct interface type.
      */
diff --git a/xmlsecurity/source/xmlsec/mscrypt/securityenvironment_mscryptimpl.cxx b/xmlsecurity/source/xmlsec/mscrypt/securityenvironment_mscryptimpl.cxx
index e7af2df..a4730c9 100644
--- a/xmlsecurity/source/xmlsec/mscrypt/securityenvironment_mscryptimpl.cxx
+++ b/xmlsecurity/source/xmlsec/mscrypt/securityenvironment_mscryptimpl.cxx
@@ -937,7 +937,7 @@ sal_Int32 SecurityEnvironment_MSCryptImpl :: verifyCertificate(
                 if ( pSimpleChain->TrustStatus.dwErrorStatus & revocationFlags)
                 {
                     //No revocation information. Because MSDN documentation is not
-                    //clear about if all other tests are performed if an error occurrs,
+                    //clear about if all other tests are performed if an error occurs,
                     //we test again, without requiring revocation checking.
                     CertFreeCertificateChain(pChainContext);
                     pChainContext = NULL;


More information about the Libreoffice-commits mailing list
diff --git a/xmlscript/source/xmldlg_imexp/xmldlg_impmodels.cxx b/xmlscript/source/xmldlg_imexp/xmldlg_impmodels.cxx
index 315c08f..424d0ab 100644
--- a/xmlscript/source/xmldlg_imexp/xmldlg_impmodels.cxx
+++ b/xmlscript/source/xmldlg_imexp/xmldlg_impmodels.cxx
@@ -1142,7 +1142,7 @@ Reference< xml::input::XElement > TitledBoxElement::startChildElement(
     // radio
     else if ( rLocalName == "radio" )
     {
         // dont create radios here, => titledbox must be inserted first due to radio grouping,
         // possible predecessors!
         Reference< xml::input::XElement > xRet(
             new RadioElement( rLocalName, xAttributes, this, _pImport ) );
@@ -1273,7 +1273,7 @@ Reference< xml::input::XElement > RadioGroupElement::startChildElement(
     // radio
     else if ( rLocalName == "radio" )
     {
         // dont create radios here, => titledbox must be inserted first due to radio grouping,
         // possible predecessors!
         Reference< xml::input::XElement > xRet(
             new RadioElement( rLocalName, xAttributes, this, _pImport ) );
@@ -1589,7 +1589,7 @@ void CheckBoxElement::endElement()
     }
     else
     {
-        sal_Int16 nVal = (bTriState ? 2 : 0); // if tristate set, but checked omitted => dont know!
+        sal_Int16 nVal = (bTriState ? 2 : 0); // if tristate set, but checked omitted => don't know!
         xControlModel->setPropertyValue( "State", makeAny( nVal ) );
     }
 
@@ -1142,7 +1142,7 @@ Reference< xml::input::XElement > TitledBoxElement::startChildElement(
     else if ( rLocalName == "radio" )
     {
-        // dont create radios here, => titledbox must be inserted first due to radio grouping,
+        // don't create radios here, => titledbox must be inserted first due to radio grouping,
         // possible predecessors!
         Reference< xml::input::XElement > xRet(
@@ -1273,7 +1273,7 @@ Reference< xml::input::XElement > RadioGroupElement::startChildElement(
     else if ( rLocalName == "radio" )
     {
-        // dont create radios here, => titledbox must be inserted first due to radio grouping,
+        // don't create radios here, => titledbox must be inserted first due to radio grouping,
         // possible predecessors!
         Reference< xml::input::XElement > xRet(